@@ -1,11 +1,23 @@
-calc_ehh <- function(haplohh,mrk,limhaplo = 2,limehh = 0.05,maxgap = NA,plotehh = TRUE,lty = 1,lwd = 1.5,col = c("blue","red"),xlab = "Position",ylab = expression(Extended~haplotype~homozygosity~(italic(EHH))),cex.lab = 1.25,main = NA,cex.main = 1.5) {
-	
-	if (!(is.haplohh(haplohh))) {stop("The data are not formatted as a valid haplohh object... (see the data2haplohh() function)")} 
-	if (mrk < 1 | mrk > haplohh@nsnp) {stop(paste("The focal SNP index must lie between",1,"and",haplohh@nsnp))}
+calc_ehh <- function(haplohh,mrk,limhaplo = 2,limehh = 0.05,maxgap = NA,discard_integration_at_border = TRUE,plotehh = TRUE,lty = 1,lwd = 1.5,col = c("blue","red"),xlab = "Position",ylab = expression(Extended~haplotype~homozygosity~(italic(EHH))),cex.lab = 1.25,main = NA,cex.main = 1.5) {
+
+	if (!(is.haplohh(haplohh))) {stop("The data are not formatted as a valid haplohh object... (see the data2haplohh() function)")}
+  if(is.numeric(mrk)){
+    mrk=as.integer(mrk)
+    if(mrk<1){
+      stop(paste0("No marker numbers smaller than 1 allowed"))
+    }
+    if(mrk>haplohh@nsnp){
+      stop(paste0("The marker number ",mrk," is bigger than the number of SNPs in the data set (",haplohh@nsnp,")"))
+    }
+  }else{
+    mrk = as.character(mrk)
+    if (!(mrk %in% haplohh@snp.name)) {stop(paste0("A marker with name '",mrk,"' is not contained in the data set"))}
+    mrk = which(haplohh@snp.name == mrk)
+  }
 	if (limhaplo < 2) {stop("limhaplo must be larger than 1")}
 	if (limehh < 0 | limehh > 1) {stop("limehh must lie between 0 and 1")}
 	if (is.na(maxgap)) {maxgap = (max(haplohh@position) + 1)}
-	
+
 	ehh <- nhaplo_eval <- matrix(0,nrow = haplohh@nsnp,ncol = 2)
 	ihh <- rep(0,2)
 	res.ehh <- .C("CALL_EHH",
@@ -15,6 +27,7 @@ calc_ehh <- function(haplohh,mrk,limhaplo = 2,limehh = 0.05,maxgap = NA,plotehh
   				number_chromosomes = as.integer(haplohh@nhap),
   				number_haplotypes = as.integer(nhaplo_eval),
   				min_number_haplotypes = as.integer(limhaplo),
+				discard_integration_at_border = as.integer(discard_integration_at_border),
   				min_EHH = as.double(limehh),
   				max_gap = as.double(maxgap),
   				map = as.double(haplohh@position),
@@ -46,8 +59,9 @@ calc_ehh <- function(haplohh,mrk,limhaplo = 2,limehh = 0.05,maxgap = NA,plotehh
 				scale <- 1e9
 				unit = "(Gb)"
 			}
-			dev.new()
-			plot.new()
+		    if (!is.null(names(dev.list())) && ((names(dev.cur()) == "windows") | (names(dev.cur()) == "X11") | (names(dev.cur()) == "quartz"))) {
+   		    		dev.new()
+    		}
 			par(mar = c(5,5,4,2) + 0.1)
 			matplot(haplohh@position[sel_reg] / scale,t(ehh[,sel_reg]),col = col,type = "l",lty = lty,lwd = lwd,main = main,bty = "n",xlab = paste(xlab,unit),ylab = ylab,cex.lab = cex.lab, cex.main = cex.main)
 			abline(v = haplohh@position[mrk] / scale,lty = 2)
